==> jc-1.4.0.tar.gz: javax/crypto/spec/DESedeKeySpec.h <==
// public class javax.crypto.spec.DESedeKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7825ceeafd22c984 javax_crypto_spec_DESedeKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DESedeKeySpec_H_
#define _JC_javax_crypto_spec_DESedeKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DESedeKeySpec$sub_refs	_jc_javax_crypto_spec_DESedeKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DESedeKeySpec$sub_nonrefs	_jc_javax_crypto_spec_DESedeKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DESedeKeySpec$refs	_jc_javax_crypto_spec_DESedeKeySpec$refs;
typedef struct _jc_javax_crypto_spec_DESedeKeySpec$nonrefs	_jc_javax_crypto_spec_DESedeKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DESedeKeySpec$object	_jc_javax_crypto_spec_DESedeKeySpec$object;

typedef struct _jc_javax_crypto_spec_DESedeKeySpec$fields_struct	_jc_javax_crypto_spec_DESedeKeySpec$fields_struct;
typedef const struct _jc_javax_crypto_spec_DESedeKeySpec$vmethods	_jc_javax_crypto_spec_DESedeKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DESedeKeySpec$vtable	_jc_javax_crypto_spec_DESedeKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_DESedeKeySpec$vtype	_jc_javax_crypto_spec_DESedeKeySpec$vtype;

// Class fields structure
struct _jc_javax_crypto_spec_DESedeKeySpec$fields_struct {
	jint	DES__5fEDE__5fKEY__5fLEN;
};
extern _jc_javax_crypto_spec_DESedeKeySpec$fields_struct _jc_javax_crypto_spec_DESedeKeySpec$class_fields;

// Constructors
extern void _jc_javax_crypto_spec_DESedeKeySpec$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_javax_crypto_spec_DESedeKeySpec$object *, struct _jc_byte_array *);
extern void _jc_javax_crypto_spec_DESedeKeySpec$method$_init$6b9b44bc28d43597(_jc_env *, struct _jc_javax_crypto_spec_DESedeKeySpec$object *, struct _jc_byte_array *, jint);

// Virtual methods
extern _jc_byte_array *_jc_javax_crypto_spec_DESedeKeySpec$method$getKey$6ddd922de8555435(_jc_env *, struct _jc_javax_crypto_spec_DESedeKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DESedeKeySpec$method_info$getKey$6ddd922de8555435;

// Static methods
extern jboolean _jc_javax_crypto_spec_DESedeKeySpec$method$isParityAdjusted$8495d84f2120000f(_jc_env *, struct _jc_byte_array *, jint);

// Virtual methods structure
struct _jc_javax_crypto_spec_DESedeKeySpec$vmethods {
	_jc_byte_array	*(*getKey$6ddd922de8555435)(_jc_env *, struct _jc_javax_crypto_spec_DESedeKeySpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_DESedeKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DESedeKeySpec$vmethods	javax_crypto_spec_DESedeKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_DESedeKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DESedeKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DESedeKeySpec$sub_refs {
	_jc_byte_array	*key;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DESedeKeySpec$refs {
    _jc_javax_crypto_spec_DESedeKeySpec$sub_refs	javax_crypto_spec_DESedeKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DESedeKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DESedeKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DESedeKeySpec$sub_nonrefs	javax_crypto_spec_DESedeKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DESedeKeySpec$object {
	_jc_javax_crypto_spec_DESedeKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DESedeKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_DESedeKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DESedeKeySpec$vtype _jc_javax_crypto_spec_DESedeKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DESedeKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DESedeKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_DESedeKeySpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/DESedeKeySpec.h <==
// public class javax.crypto.spec.DESedeKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7825ceeafd22c984 javax_crypto_spec_DESedeKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DESedeKeySpec_H_
#define _JC_javax_crypto_spec_DESedeKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DESedeKeySpec$sub_refs	_jc_javax_crypto_spec_DESedeKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DESedeKeySpec$sub_nonrefs	_jc_javax_crypto_spec_DESedeKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DESedeKeySpec$refs	_jc_javax_crypto_spec_DESedeKeySpec$refs;
typedef struct _jc_javax_crypto_spec_DESedeKeySpec$nonrefs	_jc_javax_crypto_spec_DESedeKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DESedeKeySpec$object	_jc_javax_crypto_spec_DESedeKeySpec$object;

typedef struct _jc_javax_crypto_spec_DESedeKeySpec$fields_struct	_jc_javax_crypto_spec_DESedeKeySpec$fields_struct;
typedef const struct _jc_javax_crypto_spec_DESedeKeySpec$vmethods	_jc_javax_crypto_spec_DESedeKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DESedeKeySpec$vtable	_jc_javax_crypto_spec_DESedeKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_DESedeKeySpec$vtype	_jc_javax_crypto_spec_DESedeKeySpec$vtype;

// Class fields structure
struct _jc_javax_crypto_spec_DESedeKeySpec$fields_struct {
	jint	DES__5fEDE__5fKEY__5fLEN;
};
extern _jc_javax_crypto_spec_DESedeKeySpec$fields_struct _jc_javax_crypto_spec_DESedeKeySpec$class_fields;

// Constructors
extern void _jc_javax_crypto_spec_DESedeKeySpec$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_javax_crypto_spec_DESedeKeySpec$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_spec_DESedeKeySpec$method$_init$6b9b44bc28d43597(_jc_env *, struct _jc_javax_crypto_spec_DESedeKeySpec$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_javax_crypto_spec_DESedeKeySpec$method$getKey$6ddd922de8555435(_jc_env *, struct _jc_javax_crypto_spec_DESedeKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DESedeKeySpec$method_info$getKey$6ddd922de8555435;

// Static methods
extern jboolean _jc_javax_crypto_spec_DESedeKeySpec$method$isParityAdjusted$8495d84f2120000f(_jc_env *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_crypto_spec_DESedeKeySpec$vmethods {
	_jc_byte_array	*(*getKey$6ddd922de8555435)(_jc_env *, struct _jc_javax_crypto_spec_DESedeKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_DESedeKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DESedeKeySpec$vmethods	javax_crypto_spec_DESedeKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_DESedeKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DESedeKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DESedeKeySpec$sub_refs {
	_jc_byte_array	*key;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DESedeKeySpec$refs {
    _jc_javax_crypto_spec_DESedeKeySpec$sub_refs	javax_crypto_spec_DESedeKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DESedeKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DESedeKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DESedeKeySpec$sub_nonrefs	javax_crypto_spec_DESedeKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DESedeKeySpec$object {
	_jc_javax_crypto_spec_DESedeKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DESedeKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_DESedeKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DESedeKeySpec$vtype _jc_javax_crypto_spec_DESedeKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DESedeKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DESedeKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_DESedeKeySpec_H_ */
